# DB Scheduler
A custom database timer handler, so if your application restarts, your timers still run!

This is a simple database scheduling system, that allows for your program, to be scheduled.

Documentation: [here](https://db-scheduler.mplaty.com/)

Github: [Here](https://github.com/MPlatypus/db-scheduler/)